#### Disclaimer on Error Reporting

_By implementing this SDK, you acknowledge and agree that the SDK may automatically send error reports to our servers. These reports are strictly limited to information relevant for identifying and resolving issues, such as error messages, stack traces (including file paths that may include your system username), and the SDK version. Our primary aim in collecting this data is to enhance the developer experience by identifying, diagnosing, and fixing issues more efficiently. No personal information or sensitive data will be transmitted as part of these reports without your explicit consent._

_This collection is in compliance with the California Consumer Privacy Act (CCPA). We commit to not selling your Personal Information and ensuring its confidentiality and security. California residents have the right to know about, access, and delete their Personal Information collected by us. For details on how to exercise these rights, please refer to our [Privacy Policy](https://docs.google.com/document/d/1SjWwa8nhHFLXa0ytSHv5F7osfNDclA6GU9-RvTevGDs/edit?usp=sharing). Our policy also includes information on how to opt-out of the sale of Personal Information, though we do not engage in this practice._
